import numpy as np
from scipy.io.wavfile import write
import pretty_midi
from IPython.display import Audio
from IPython.core.display import display

class MidiSynth(object):
    def __init__(self, path_sf=None):
        self.path_sf = path_sf
        
    def play_midi(self, path_midi):
        a_1 = self._read_midi(path_midi)
        display(Audio(a_1, rate=44100))
    
    def _read_midi(self, path_midi):
        midi_data = pretty_midi.PrettyMIDI(path_midi)
        a_1 = midi_data.fluidsynth(sf2_path=self.path_sf)
        return a_1
    
    def midi2audio(self, path_midi, path_out='output.mp3'):
        a_1 = self._read_midi(path_midi)
        write(path_out, 44100, a_1)  
        


from setuptools import setup, find_packages

setup(
    name='midiSynth',
    version='0.1',
    description='',
    author='annahung31',
    author_email='fbiannahung@gmail.com',
    url='https://github.com/annahung31/midi_synth.git',
    packages=find_packages(),
    package_data={'': ['examples_data/*']},
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Topic :: Multimedia :: Sound/Audio :: MIDI",
    ],
    keywords='music midi mir',

    license='MIT',
    install_requires=[
        'numpy >= 1.19.5',
        'scipy >= 1.5.4',
        'pretty_midi >= 0.2.9',
        'ipython >= 7.16.1'
    ]
)


"""
python setup.py sdist
twine upload dist/*
"""